
{ config, pkgs, inputs, ... }:

{
  imports =
    [
      ../shared/shared-configuration.nix
      ./kernighan-hardware.nix
      ./services/nginx.nix
      ./services/home_assistant.nix
    ];

  networking = {
    hostName = "kernighan";
    firewall = {
      enable = true;
      allowedTCPPorts = [ 8123 2223 80 443 ];
    };
    interfaces = {
       end0.ipv4.addresses = [{
         address = "192.168.40.25";
         prefixLength = 24;
       }];
       end0.ipv6.addresses = [{
         address = "fe80::dea6:32ff:fe04:c6f3";
         prefixLength = 64;
       }];
    };
    defaultGateway = "192.168.40.1";
    defaultGateway6.address = "fe80::00:b8:c2:db:b8:57";
    defaultGateway6.interface = "end0";
    nameservers = [ "208.67.222.222" "208.67.220.220" ];
  };

  boot.loader.grub.enable = false;
  boot.loader.generic-extlinux-compatible.enable = true;

  environment.systemPackages = with pkgs; [
    git
    vim
  ];

  nix.buildMachines = [ {
    hostName = "kernighan";
    system = "x86_64-linux";
    protocol = "ssh-ng";
    maxJobs = 1;
    speedFactor = 2;
    supportedFeatures = [ "nixos-test" ];
  } ];
  nix.distributedBuilds = true;
  nix.extraOptions = ''
    builders-use-substitutes = true
  '';
}
